<?php
/**
 * Navigation Menu Functions.
 *
 * @package			Wordsmith
 * @copyright		Copyright (C) 2013 Victor Sarabia
 * @license			http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2
 * @since			Wordsmith 0.1
 */




/**
 * Create HTML list of nav menu items.
 *
 * @uses Walker_Nav_Menu
 */
class Wordsmith_Walker_Nav_Menu extends Walker_Nav_Menu {

	/**
	 * Used to filter allowed CSS class names
	 */
	var $allowed_css_classes = array(
		'current-menu-item',
		'current-menu-ancestor',
		'menu-link',
		'sub-menu-link',
		'tab-menu-link',
		'has-children'
	);

	function filter_css_classes( $class_names = array(), $item, $args ) {
		return array_intersect( $this->allowed_css_classes, $class_names );
	}

	/**
	 * @see Walker_Nav_Menu::start_el()
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item Menu item data object.
	 * @param int $depth Depth of menu item. Used for padding.
	 * @param int $current_page Menu item ID.
	 * @param object $args
	 */
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		// Link Classes
		$class_names = '';
		$classes = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = $depth == 0 ? 'menu-link' : 'sub-menu-link';
		if ( $depth == 0 ) {
			$classes[] = 'tab-menu-link';
		}
		add_filter( 'nav_menu_css_class', array( $this, 'filter_css_classes' ), 10, 3 );
		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

		// Item Classes
		$item_classes = array();
		$item_classes[] = $depth == 0 ? 'menu-item' : 'sub-menu-item';
		$item_classes[] = $depth == 0 ? 'tab-menu-item' : '';
		$item_classes[] = ( in_array( 'has-children', $classes ) ) ? 'menu-item-parent' : '';
		$item_classes = implode( ' ', $item_classes );

		$id = apply_filters( 'nav_menu_item_id', '', $item, $args );
		$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

		$output .= $indent . '<li class="' . $item_classes . '"' . $id . '>';

		$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
		$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
		$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
		$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $class_names . $attributes .'>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}

	/**
	 * @see Walker_Nav_Menu::end_el()
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item Page data object. Not used.
	 * @param int $depth Depth of page. Not Used.
	 */
	function end_el( &$output, $item, $depth = 0, $args = array() ) {
		$output .= "</li>\n";
	}

	/**
	 * @see Walker::display_element()
	 *
	 * @param object $element Data object
	 * @param array $children_elements List of elements to continue traversing.
	 * @param int $max_depth Max depth to traverse.
	 * @param int $depth Depth of current element.
	 * @param array $args
	 * @param string $output Passed by reference. Used to append additional content.
	 * @return null Null on failure with no changes to parameters.
	 */
	function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {

		if ( ! empty( $children_elements[ $element->ID ] ) && $depth == 0 ) {
			$element->classes[] = 'has-children';
		}
		parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );

	}
}




/**
 * Displays a navigation menu.
 *
 * @uses		wp_nav_menu()
 */
function wordsmith_nav_menu( $menu_location = '' ) {

	$args = array();

	// Only continue if the requested menu location has a menu assigned to it
	if ( has_nav_menu( $menu_location ) ) {
		$args['theme_location'] = $menu_location;
	}
	else {
		return '';
	}

	// How many levels of the hierarchy are to be included
	$args[ 'depth' ] = 2;
	// Do not fallback to wp_page_menu
	$args[ 'fallback_cb' ] = false;
	// Wrap the menu items in a <ul> tag
	$args[ 'items_wrap' ] = '<ul class="%2$s">%3$s</ul>';
	// CSS class assigned to the menu <ul> tag
	$args[ 'menu_class' ] = 'tabbed-menu menu clearfix';
	// Wrap the menu in a <nav> tag
	$args[ 'container' ] = 'nav';
	// CSS class assigned to the <nav> tag
	$args[ 'container_class' ] = 'tabbed-menu-container';
	// Use custom Wordsmith_Walker_Nav_Menu class
	$args[ 'walker' ] = new Wordsmith_Walker_Nav_Menu;

	wp_nav_menu( $args );
}